#!/bin/bash

source /etc/mod-hardware-descriptor.env

if [ -n "${DMA_IRQ}" ]; then
    DMA_PID=$(/usr/bin/ps -e | /usr/bin/grep irq/${DMA_IRQ} | /usr/bin/awk '{print $1}')
    /usr/bin/chrt -f -p 91 ${DMA_PID}
fi

if [ -n "${I2C_IRQ}" ]; then
    I2C_PID=$(/usr/bin/ps -e | /usr/bin/grep irq/${I2C_IRQ} | /usr/bin/awk '{print $1}')
    /usr/bin/chrt -f -p 74 ${I2C_PID}
fi

if [ -n "${MIDI_IRQ}" ]; then
    MIDI_PID=$(/usr/bin/ps -e | /usr/bin/grep irq/${MIDI_IRQ} | /usr/bin/awk '{print $1}')
    /usr/bin/chrt -f -p 73 ${MIDI_PID}
fi

if [ -n "${USB_IRQ}" ]; then
    USB_PID=$(/usr/bin/ps -e | /usr/bin/grep irq/${USB_IRQ} | /usr/bin/awk '{print $1}')
    # USB IRQ is sometimes only active if a usb host or gadget is plugged in
    if [ -n "${USB_PID}" ]; then
        # we can have 2 processes handling usb
        if [ "$(/usr/bin/echo ${USB_PID} | /usr/bin/wc -w)" -eq 2 ]; then
            USB_PIDS=($(/usr/bin/echo ${USB_PID}))
            /usr/bin/chrt -f -p 72 ${USB_PIDS[0]}
            /usr/bin/chrt -f -p 72 ${USB_PIDS[1]}
        else
            /usr/bin/chrt -f -p 72 ${USB_PID}
        fi
    fi
fi

# For legacy Duos, we need some trickery around the "bad" CPU (1 of the 2 has more latency, randomly)
if [ "${PLATFORM}" = "duo" ] && [ -z "${KERNEL_MAINLINE}" ]; then
    CYCLERES=$(/usr/bin/cyclictest --smp -p1 -D1s -q | /usr/bin/tail -n 1 | /usr/bin/awk '{print $NF}')
    if [ "${CYCLERES}" -lt 1000 ]; then
        # Max < 1000, bad CPU #2
        /usr/bin/echo 2 > /proc/irq/${DMA_IRQ}/smp_affinity
        /usr/bin/echo 2 > /proc/irq/${I2C_IRQ}/smp_affinity
        /usr/bin/echo 1 > /proc/irq/${CC_IRQ}/smp_affinity
        /usr/bin/echo 1 > /proc/irq/${USB_IRQ}/smp_affinity
        /usr/bin/echo 1 > /proc/irq/default_smp_affinity
    else
        # Max >= 1000, bad CPU #1
        /usr/bin/echo 1 > /proc/irq/${DMA_IRQ}/smp_affinity
        /usr/bin/echo 1 > /proc/irq/${I2C_IRQ}/smp_affinity
        /usr/bin/echo 2 > /proc/irq/${CC_IRQ}/smp_affinity
        /usr/bin/echo 2 > /proc/irq/${USB_IRQ}/smp_affinity
        /usr/bin/echo 2 > /proc/irq/default_smp_affinity
    fi
fi

exit 0
