#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# MOD Duo hardware tests
# Copyright (C) 2016-2020 Filipe Coelho <falktx@falktx.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License, or any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# For a full copy of the GNU General Public License see the LICENSE file.

# ------------------------------------------------------------------------------------------------------------
# Imports

# from extra libraries
from serial import Serial

# local
from config import devInfo, testStream
from test_abstract import ExtendedTestCase

# ------------------------------------------------------------------------------------------------------------

class TestControlChainLoopback(ExtendedTestCase):
    kTestDataBuf = b"\x90\x64\x64\x80\x64\x00"
    kTestDataSize = 6

    def setUp(self):
        self.serial = Serial(devInfo.cc_serial_port, devInfo.cc_baud_rate, timeout=0.1)

    # Test connected
    def test_1_loopback_on(self):
        # flush
        self.serial.readall()

        # first test read, must be empty
        try:
            self.assertEqual(self.serial.readall(), b"")
        except AssertionError as e:
            testStream.print("Data read in ControlChain serial port where none was expected")
            raise e

        # write data
        try:
            self.assertEqual(self.serial.write(self.kTestDataBuf), self.kTestDataSize)
        except AssertionError as e:
            testStream.print("Failed to write data to ControlChain serial port")
            raise e

        # test read, must be equal to previous write
        try:
            self.assertEqual(self.serial.readall(), self.kTestDataBuf)
        except AssertionError as e:
            testStream.print("Failed to read data from ControlChain serial port")
            raise e

        # final test read, must be empty again
        try:
            self.assertEqual(self.serial.readall(), b"")
        except AssertionError as e:
            testStream.print("Data read in ControlChain serial port where none was expected")
            raise e

# ------------------------------------------------------------------------------------------------------------

tests = [
    TestControlChainLoopback
]

# ------------------------------------------------------------------------------------------------------------
