#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# MOD Duo hardware tests
# Copyright (C) 2016-2020 Filipe Coelho <falktx@falktx.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License, or any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# For a full copy of the GNU General Public License see the LICENSE file.

# ------------------------------------------------------------------------------------------------------------
# Imports

# additional stuff
from time import sleep

# from extra libraries
from smbus import SMBus

# local
from config import devInfo, testStream
from test_abstract import ExtendedTestCase

# ------------------------------------------------------------------------------------------------------------

class Test_uid_eeprom(ExtendedTestCase):
    kTestDataBuf = [170]

    def setUp(self):
        self.i2cbus = SMBus(devInfo.i2c_main_bus)

        self.address = 0x50
        self.test_offset = 0x20
        self.test_size = 1

    # Test connected
    def test_1_read_write(self):

        # test read, we get the first part of a potential key, or random data
        try:
            first_key_byte = self.i2cbus.read_i2c_block_data(self.address, self.test_offset, 1)
        except AssertionError as e:
            testStream.print("Failed to read data from eeprom memory")
            raise e

        sleep(0.1)

        # write a different byte back
        try:
            self.i2cbus.write_i2c_block_data(self.address, self.test_offset, self.kTestDataBuf)
        except AssertionError as e:
            testStream.print("Failed to write data to eeprom IC")
            raise e

        sleep(0.1)

        # read the same register, should get the byte we have just written
        try:
            self.assertEqual(self.i2cbus.read_i2c_block_data(self.address, self.test_offset, 1), self.kTestDataBuf)
        except AssertionError as e:
            testStream.print("Failed to read data from eeprom memory")
            raise e

        sleep(0.1)

        # write the potential key byte back
        try:
            self.i2cbus.write_i2c_block_data(self.address, self.test_offset, first_key_byte)
        except AssertionError as e:
            testStream.print("Failed to write data to eeprom IC")
            raise e

        sleep(0.1)

        # test read, must be equal to the original
        try:
            self.assertEqual(self.i2cbus.read_i2c_block_data(self.address, self.test_offset, 1), first_key_byte)
        except AssertionError as e:
            testStream.print("Read data from eeprom is not the same as written data")
            raise e

# ------------------------------------------------------------------------------------------------------------

tests = [
    Test_uid_eeprom
]

# ------------------------------------------------------------------------------------------------------------
